pub mod async_fifo;
pub mod cross_fifo;
pub mod dff;
pub mod edge_detector;
pub mod fifo_expander_n;
pub mod fifo_logic;
pub mod fifo_reducer;
pub mod fifo_reducer_n;
pub mod prelude;
pub mod pulser;
pub mod pwm;
pub mod ram;
pub mod rom;
pub mod shot;
pub mod spi_master;
pub mod spi_slave;
pub mod strobe;
pub mod sync_fifo;
pub mod sync_rom;
pub mod synchronizer;
pub mod accum;
pub mod mac_fir;
pub mod tristate;
pub mod bidirectional_bus;
